CookieManagerKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CookieManagerKitPlatform
Implementers

Constructors

CookieManagerKitPlatform()
Constructs a CookieManagerKitPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllCookies() → Future<void>
loadCookies({required String url}) → Future<List<Cookie>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveCookies({required String url, required List<Cookie> cookies}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CookieManagerKitPlatform
The default instance of CookieManagerKitPlatform to use.
getter/setter pair